TORIBASH GAME MANUAL

Thank you for downloading Toribash: Violence Perfected.

INFORMATION

Stay in contact with Nabi Studios: hampa@nabistudios.com

Like the Toribash Facebook Fan Page: https://www.facebook.com/pages/Toribash/61341947104?ref=hl

Follow Toribash on Twitter: https://twitter.com/Toribash and https://twitter.com/TORIBASHNetwork

TORIBASH Trailers, Beta Footage, Montages and more: http://www.youtube.com/user/hampa999

TORIBASH eSports, Tutorials, Analysis and more: http://www.youtube.com/TORIBASHNetwork

Watch Toribash Live Broadcasts on TwitchTV: http://www.twitch.tv/directory/game/Toribash

QUICK START

Click joints to manipulate character. Hit Space when ready with move. Control camera with WASD keys.

BASIC CONTROLS

Click a joint to change joint state (Relax/Hold/Extend/Contract).

Scrolling the mouse wheel up or down on a joint will change joint state also.

Left mouse click on hands to prepare it for gripping.

HOTKEYS

BASICS

W,A,S,D & shift + W,A,S,D - Camera controlling
F - Save a replay
G - Enable/disable your puppet's ghost
B - Enable/disable both puppets' ghosts
C - Hold all / relax all
L - Grabs/ungrabs when moving cursor on the non-fractured/non-dismembered wrist
V - Grabs/ungrabs both hands
Z - Extends/contracts the joint
X - Holds/relaxes the joint

1 - Default camera

2 - Free camera, use W/A/S/D/Q/E + Shift to control

3 - Tori Camera

4 - Uke Camera

REPLAY VIEWING

ctrl + ] - Play the next replay
ctrl + [ - Play the previous replay
R - Play the replay from its beginning
P - Pause

shift + P - Play the replay frame-by-frame

E - Enter the replay editing mode
K - Save the keyframe
I - Delete all the keyframes

. - Speed up replay.

, - Slow down replay.

SINGLEPLAYER (FREE PLAY)

ctrl + N - Start making a new replay

CHAT

Enter/T - Open a chat window
~ - Displays/Hides the previous chat and command lines.
Page up - Scroll the chat up
Page down - Scroll the chat down
Home - Scroll the chat to its beginning
End - Scroll the chat to the end

OTHER

ctrl + L - Open the flame forge menu
ctrl + Y - Show the sound menu
ctrl + U - Enter the matchmaking mode
ctrl + J - Enter the flame browser
ctrl + M - Enter the mods menu
ctrl + G - Show the game rules
ctrl + H - Enter the shader menu
ctrl + enter - Fullscreen mode

ctrl + B - Open buddy list
f5/f6/f7/f8 - Take a screenshot
ctrl + f7 - Take every frame's shot into a .pov file

MENU OPTIONS

FREE PLAY - Start a new Single player game.

MULTIPLAYER - Opens up the list of servers, after choosing a server you will be taken into the current game.

MATCHMAKING – Toribash tries to find you a match for the mod/game mode of your choosing.

FIGHT SCHOOL - Go into the fight school menu, which consists of the following:

TORIBASH TUTORIAL – Learn how to play Toribash.

BASIC TRAINING - Learn basic Toribash moves.

ADVANCED MOVES – Learn advanced Toribash moves.

CHALLENGE UKE – Fight the CPU.

TORISHOP - Open up the Torishop menu where you can buy things like textures, blood colors and more.

SETUP - Go into the game settings menu, which consists of the following:

OPTIONS -

MODS - Choose a game mod/mode to play.

UTILS – Opens a menu, which consists of the following:

SHADERS - Choose a shader to use in the game. The shaders change the game environment.

FLAME FORGE – Create a flame for your avatar.

FLAME BROWSER -

MOD MAKER – Create mods/game modes.

SCRIPTS - Choose a script to use in the game. Scripts usually edit the gameplay in some way.

SOUNDS – Enable or disable game sounds.

REPLAYS - Lists all of your replays. Click on a replay to view it.
GAME RULES - Change rules about the behavior of the fights.
LOGIN - Specify your Toribash account here.

QUIT - Closes the application.

GHOSTING

To preview your move a ghost of your character is shown. Only the selected
character is ghosted. Both characters can be ghosted with the 'B' key.

SCORING

Toribash uses location based damages. Hitting head causes most damage.
Feet, Hands, Knees and Elbows does not take any damage. A hit body part turns red. The deeper the red the more damage that’s been done.

DISMEMBERMENTS

A hard blow can break a joint. Joints are the weakest when they have just been
hit (and are drawn in red). If a joint isn't hit for a little while, its current damage will lower
gradually. Once a joint breaks it can no longer be used. The body part will separate and the joint will be in a deep red, and bleed.

FRACTURES

A hard blow can break a joint. Joints are the weakest when they have just been
hit (and are drawn in red). If a joint isn't hit for a little while, its current damage will lower
gradually. Once a joint is fractured it can no longer be used. The body part will move according to momentum, even bending backwards, and will be drawn in blue. Fractured body parts cannot be dismembered.
GRIPPING

Clicking left or right hand prepares it for gripping. A player can both grip
the other player and himself. To release the grip, click on the hand once more. Grips are shown with a green transparent sphere. Grip toggle can also be done by pressing the “v” key.
DISQUALIFICATIONS

Only hand and feet are allowed to touch the ground. A player who touches the
ground with any other body part or joint is disqualified. When this happens a circle is drawn in the color of the player that lost (red or blue). The origin of the circle is where the body part touched the ground.

GENERAL ADVICE

In multiplayer, focus on balance over impact velocity.

A player that uses 90% of his power and can maintain his balance usually comes out on top.

Punching is more about controlling upper body than actual arms (a bit like in real boxing).

In Free Play, select player with left mouse button.

If you have any game problems, please email: support@toribash.com

VIDEO TUTORIALS

You will make your own moves someday.

But for now, learn from video tutorials below:

http://www.youtube.com/playlist?list=PL81E557E6BCE000F2

http://www.youtube.com/playlist?list=PLA70F93975EB6D80C

SINGLEPLAYER (FREE PLAY)

This is training mode. Practice your opener moves on Uke, you training partner. This game mode allows you to make cool replays as well. No time limit. No pressure.

MULTIPLAYER

Play Judo, Aikido and more against players from around the world right here.
You have a set amount of time for each round to prepare your move. Prepare your move and when ready, hit SPACE. Both players prepare move at the same time. The player with the most points when the timer hits 0 is the winner. You get DISQUALIFIED (for some mods like Aikido) if anything but hands and feet touch the ground. In most lobbies, winner stays and loser is put in queue among the other players. Toribash is played with a central server that manages the game. The server IP is visible in the Multiplayer screen.

EDIT REPLAYS

It's possible to modify an existing replay. To do this you must first hit PAUSE
key 'p' at your desired point and then the edit key 'e'. This will put the replay in EDIT mode and you can continue tweaking the replay from that point on. When you are done you must save fight with a new name. The existing fight will still be there under it's original name. SHIFT+P can be used to step the replay one frame at the time until you find the best frame for editing.

HOW TO ADJUST REPLAY SPEED

If you want to slow a replay down, speed a replay up, pause the replay or rewind the replay, press “,” to slow down and press “.” to speed up. There's a speed meter in the bottom right corner of the screen. You'll notice a change when you slow down or speed up the replay. This feature is available in singleplayer and multiplayer. You can even you this feature when spectating matches.

IN-GAME COMMANDS

STANDARD COMMANDS

*To use these commands you don't need any server privileges

/join [room] (/jo) - Enter the room.

*If it does not exist it will be created and you'll become it's operator (You'll have @ in front of your nickname).

/spec (/sp) - Join the spectators.

/enter (/en) - Enters the fight queue.

/pass [password] (/pa) - You have to type this command if the room is protected by the password.

/emote [text] (/em) - Shows the text above your Tori's head.

/shout [text] (/sh) - Shows the 3D text in front of your camera's current position.

*The Toribash font (BadaBoom BB Edit) doesn't support some symbols so they'll be shown as rectangles.

/whisper [nickname] (/wh) - Opens the private chat tab.

/login [nickname] [password] (/lo) - Command used for logging in.

/rememberme (/rm) - Remembers current account's nickname and password.

/forgetme (/fm) - Forgets current account's nickname and password.

/search [nickname] (/sa) - Search the player among everybody who's online for the moment.

/refresh (/rf) - Refresh the server list. This command is recommended to use before /sa for better searching.

/quit (/qu) - Closes the client.
/help –This will give you help with all the command lines.
/altimeter 0|1 (/am) - Enables/disables the altimeter. This will display the height information of your highest body part.

/speedometer 0|1 (/sm) - Enables/disables the speedometer.

/damagemeter 0|1 (/dm) – This allows you to see the damage a joint took during a hit. Hover the cursor over a joint and the damage is shown on the meter.

/atmo – This will open the Toribash Atmospheres fight stage menu

MORE COMMANDS HERE: http://forum.toribash.com/showthread.php?t=317900

HOW TO GIVE YOURSELF A CLAN TAG

Go the Setup menu, click “Login” and type [YourClanTag] on the left side of your user name. Don't forget the “[“ and “]” signs. Click “Login” and you'll see your user name with a clan tag next to it when playing Toribash from now on. If it doesn’t show. Restart the game.

Example: [vVv]ToribashPlayer

REPLAYS

Replays are located in the replay subdirectory. They are plain text files with
a .rpl extension and can be easily be shared among players. Clicking on a replay file will open up Toribash and play the file. Replay authors that matches any of the textures in heads subdirectory will skin the in-game characters.

BELTS

These belts represent how much experience you have as a Toribash player. These belts give NO special abilities. They are only badges of honor.
White: 0 matches
Yellow: 20 matches
Orange: 50 matches
Green: 100 matches
Blue: 200 matches
Brown: 500 matches
Black: 1000 matches
Dan ranks are achieved after reaching black belt.
Second Dan: 2000 matches
Third Dan: 3000 matches
Fourth Dan: 4000 matches
Fifth Dan: 5000 matches
Sixth Dan: 6000 matches
Seventh Dan: 7000 matches
Eighth Dan: 8000 matches
Ninth Dan: 9000 matches
Tenth Dan: 10000 matches

These are extra belts for the highly experienced Toribash players.

Master Belt: 15000 matches
Custom Belt: 20000 matches
God Belt: 50000 matches

TORIBASH TERMS

Learn how to talk like a Toribash player. http://forum.toribash.com/showthread.php?t=105767

HOW TO EARN TORICREDITS

ToriCredits help you buy game items and textures. Watch this Tutorial on how to earn ToriCredits. http://www.youtube.com/watch?v=xYYMZyRcRdU

SCREENSHOTS

F8 will take save a screenshot. You will be able to find the screenshots folder inside the Toribash game folder.
FORUMS

The link the Toribash community forums: http://forum.toribash.com/
The forum is full of tutorials for Toribash, which house more information than we could fit into this manual come online and meet your fellow Toribashers! We have tons of experienced players that are more than happy to share there knowledge with newer players so if you are stuck on aspects of Toribash don't
be afraid to ask.

JOINTS

Ankles

The ankles are good for making your kicks land better onto an opponent.

Knees

They allow you to do many things from kicks, mostly landing properly without disqualifying. Knees are very important.

Hips

These are the keys to the majority of kicks.

Extra: A bonus about the hips, when one is contracted and the other is extended, they go further their way than when both are going the same way, unless you have extended hips and extended abs.

Glutes

These are good for dodging, saving, and getting side kicks on people.

Abs

The abs do little functions which affect you in a big way, arching your player downwards, and upwards. If you're going for an upward kick, extending would make it go higher and faster, same with a downwards kick but with contraction.

Lumbars

The lumbar simply tilts your player left or right, quite a simple function that affects how you swing in from things.

Chest

The chest rotates your Tori left and right, similar to the lumbar but by spinning.

Note: Spinning your chest to the right moves your LEFT hand closer to the opponent. You never want to accidentally spin the wrong way.

Pecs

Your pecs are the keys to punching and landing on your back, they allow you to land in the arched back position and keep DQ areas off the ground.

Shoulders

Shoulders allow you to position your arms up and down.

Elbows

Elbows are the keys to "hugging", to staying up and recovering from falling positions.

Note: Elbows, like knees, are fast and powerful. If you're grabbing someone, contract your elbow a little before you make contact and you will do MUCH more damage (but if done too soon, you could just miss and hit yourself, so timing is key)

Wrists

The wrists can do many things, such as in a grab, allowing you to properly extend an elbow or helping pull people in with a contraction.

Neck

The neck improves headbutts.

Feet (Non-Joint Info)

Feet are very important (sets how much friction on ground, important for balance, kicks and poses).

Hands (Non-Joint Info)

The hands are keys to grabbing people.

Have fun playing Toribash!

See you in-game.